@@ -1213,17 +1213,6 @@ static void InitGame()
         exit(1);
     }
 
-	system("/usr/bin/gconftool-2 -g /apps/osso/inputmethod/int_kb_layout > /home/user/int_kb_layout");
- 	FILE *archivo;
-	char caracteres[100];
-	int c;
- 	archivo = fopen("/home/user/int_kb_layout","r");
-	do { c = fscanf(archivo, "%s", caracteres); }
-    while (c != EOF); 
-	fclose(archivo);
-	if (caracteres!="us") system("/usr/bin/gconftool-2 -s /apps/osso/inputmethod/int_kb_layout us -t string");
-
-
 
     SignonScreen ();
 
@@ -1892,14 +1881,5 @@ int main (int argc, char *argv[])
     Quit("Demo loop exited???");
 
 
- 	FILE *archivo2;
-	char caracteres2[100];
-	int c2;
- 	archivo2 = fopen("/home/user/int_kb_layout","r");
-	do { c2 = fscanf(archivo2, "%s", caracteres2); }
-	while (c2 != EOF); 
-	fclose(archivo2);
-	if (caracteres2!="us") system("/usr/bin/gconftool-2 -s /apps/osso/inputmethod/int_kb_layout $(cat /home/user/int_kb_layout) -t string");
-
     return 1;
 }
